@@ -1,11 +1,14 @@
 package App::HTTPTinyUtils;
 
-our $DATE = '2019-04-15'; # DATE
-our $VERSION = '0.006'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-11-11'; # DATE
+our $DIST = 'App-HTTPTinyUtils'; # DIST
+our $VERSION = '0.007'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
+use Log::ger;
 
 use Perinci::Sub::Util qw(gen_modified_sub);
 
@@ -31,6 +34,7 @@ sub _http_tiny {
             $opts{content} = <STDIN>;
         }
 
+        log_trace "Request: $method $url ...";
         my $res0 = $class->new(%{ $args{attributes} // {} })
             ->request($method, $url, \%opts);
         my $success = $res0->{success};
@@ -113,7 +117,7 @@ sub http_tiny {
 gen_modified_sub(
     output_name => 'http_tiny_cache',
     base_name   => 'http_tiny',
-    summary => 'Perform request with HTTP::Tiny::Cache',
+    summary => 'Perform request(s) with HTTP::Tiny::Cache',
     description => <<'_',
 
 Like `http_tiny`, but uses <pm:HTTP::Tiny::Cache> instead of <pm:HTTP::Tiny>.
@@ -126,7 +130,7 @@ _
 gen_modified_sub(
     output_name => 'http_tiny_plugin',
     base_name   => 'http_tiny',
-    summary => 'Perform request with HTTP::Tiny::Plugin',
+    summary => 'Perform request(s) with HTTP::Tiny::Plugin',
     description => <<'_',
 
 Like `http_tiny`, but uses <pm:HTTP::Tiny::Plugin> instead of <pm:HTTP::Tiny>.
@@ -139,7 +143,7 @@ _
 gen_modified_sub(
     output_name => 'http_tiny_retry',
     base_name   => 'http_tiny',
-    summary => 'Perform request with HTTP::Tiny::Retry',
+    summary => 'Perform request(s) with HTTP::Tiny::Retry',
     description => <<'_',
 
 Like `http_tiny`, but uses <pm:HTTP::Tiny::Retry> instead of <pm:HTTP::Tiny>.
@@ -166,7 +170,7 @@ _
 gen_modified_sub(
     output_name => 'http_tiny_customretry',
     base_name   => 'http_tiny',
-    summary => 'Perform request with HTTP::Tiny::CustomRetry',
+    summary => 'Perform request(s) with HTTP::Tiny::CustomRetry',
     description => <<'_',
 
 Like `http_tiny`, but uses <pm:HTTP::Tiny::CustomRetry> instead of
@@ -198,6 +202,72 @@ _
     output_code => sub { _http_tiny('HTTP::Tiny::CustomRetry', @_) },
 );
 
+gen_modified_sub(
+    output_name => 'http_tiny_plugin_every',
+    base_name   => 'http_tiny',
+    summary => 'Perform request(s) with HTTP::Tiny::Plugin every N seconds, log result in a directory',
+    description => <<'_',
+
+Like `http_tiny_plugin`, but perform the request every N seconds and log the
+result in a directory.
+
+_
+    modify_meta => sub {
+        my $meta = shift;
+        $meta->{args}{every} = {
+            schema => 'duration*',
+            req => 1,
+        };
+        $meta->{args}{dir} = {
+            schema => 'dirname*',
+            req => 1,
+        };
+    },
+    output_code => sub {
+        require Log::ger::App;
+
+        my %args = @_;
+
+        my $log_dump = Log::ger->get_logger(category => 'Dump');
+
+        no warnings 'once';
+        shift @Log::ger::App::IMPORT_ARGS;
+        #log_trace("Existing Log::ger::App import: %s", \@Log::ger::App::IMPORT_ARGS);
+        Log::ger::App->import(
+            @Log::ger::App::IMPORT_ARGS,
+            outputs => {
+                DirWriteRotate => {
+                    conf => {
+                        path => $args{dir},
+                        max_size => 10_000,
+                    },
+                    level => 'off',
+                    category_level => {
+                        Dump => 'info',
+                    },
+                },
+            },
+            extra_conf => {
+                category_level => {
+                    Dump => 'off',
+                },
+            },
+        );
+
+        while (1) {
+            my $res = _http_tiny('HTTP::Tiny::Plugin', %args);
+            if ($res->[0] !~ /^(200|304)/) {
+                log_warn "Failed: $res->[1], skipped saving to directory";
+            } else {
+                $log_dump->info($res->[2]);
+            }
+            log_trace "Sleeping %s second(s) ...", $args{every};
+            sleep $args{every};
+        }
+        [200];
+    },
+);
+
 1;
 # ABSTRACT: Command-line utilities related to HTTP::Tiny
 
@@ -213,7 +283,7 @@ App::HTTPTinyUtils - Command-line utilities related to HTTP::Tiny
 
 =head1 VERSION
 
-This document describes version 0.006 of App::HTTPTinyUtils (from Perl distribution App-HTTPTinyUtils), released on 2019-04-15.
+This document describes version 0.007 of App::HTTPTinyUtils (from Perl distribution App-HTTPTinyUtils), released on 2020-11-11.
 
 =head1 SYNOPSIS
 
@@ -231,6 +301,8 @@ This distribution includes several utilities related to L<HTTP::Tiny>:
 
 =item * L<http-tiny-plugin>
 
+=item * L<http-tiny-plugin-every>
+
 =item * L<http-tiny-retry>
 
 =back
@@ -274,6 +346,7 @@ and continue. Will return with the last error response.
 
 =item * B<urls>* => I<array[str]>
 
+
 =back
 
 Returns an enveloped result (an array).
@@ -295,7 +368,7 @@ Usage:
 
  http_tiny_cache(%args) -> [status, msg, payload, meta]
 
-Perform request with HTTP::Tiny::Cache.
+Perform request(s) with HTTP::Tiny::Cache.
 
 Like C<http_tiny>, but uses L<HTTP::Tiny::Cache> instead of L<HTTP::Tiny>.
 See the documentation of HTTP::Tiny::Cache on how to set cache period.
@@ -328,6 +401,7 @@ and continue. Will return with the last error response.
 
 =item * B<urls>* => I<array[str]>
 
+
 =back
 
 Returns an enveloped result (an array).
@@ -349,7 +423,7 @@ Usage:
 
  http_tiny_customretry(%args) -> [status, msg, payload, meta]
 
-Perform request with HTTP::Tiny::CustomRetry.
+Perform request(s) with HTTP::Tiny::CustomRetry.
 
 Like C<http_tiny>, but uses L<HTTP::Tiny::CustomRetry> instead of
 L<HTTP::Tiny>. See the documentation of HTTP::Tiny::CustomRetry for more
@@ -383,6 +457,7 @@ and continue. Will return with the last error response.
 
 =item * B<urls>* => I<array[str]>
 
+
 =back
 
 Returns an enveloped result (an array).
@@ -404,7 +479,7 @@ Usage:
 
  http_tiny_plugin(%args) -> [status, msg, payload, meta]
 
-Perform request with HTTP::Tiny::Plugin.
+Perform request(s) with HTTP::Tiny::Plugin.
 
 Like C<http_tiny>, but uses L<HTTP::Tiny::Plugin> instead of L<HTTP::Tiny>.
 See the documentation of HTTP::Tiny::Plugin for more details.
@@ -437,6 +512,66 @@ and continue. Will return with the last error response.
 
 =item * B<urls>* => I<array[str]>
 
+
+=back
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (payload) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (any)
+
+
+
+=head2 http_tiny_plugin_every
+
+Usage:
+
+ http_tiny_plugin_every(%args) -> [status, msg, payload, meta]
+
+Perform request(s) with HTTP::Tiny::Plugin every N seconds, log result in a directory.
+
+Like C<http_tiny_plugin>, but perform the request every N seconds and log the
+result in a directory.
+
+This function is not exported.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<attributes> => I<hash>
+
+Pass attributes to HTTP::Tiny constructor.
+
+=item * B<content> => I<str>
+
+=item * B<dir>* => I<dirname>
+
+=item * B<every>* => I<duration>
+
+=item * B<headers> => I<hash>
+
+=item * B<ignore_errors> => I<bool>
+
+Ignore errors.
+
+Normally, when given multiple URLs, the utility will exit after the first
+non-success response. With C<ignore_errors> set to true, will just log the error
+and continue. Will return with the last error response.
+
+=item * B<method> => I<str> (default: "GET")
+
+=item * B<raw> => I<bool>
+
+=item * B<urls>* => I<array[str]>
+
+
 =back
 
 Returns an enveloped result (an array).
@@ -458,7 +593,7 @@ Usage:
 
  http_tiny_retry(%args) -> [status, msg, payload, meta]
 
-Perform request with HTTP::Tiny::Retry.
+Perform request(s) with HTTP::Tiny::Retry.
 
 Like C<http_tiny>, but uses L<HTTP::Tiny::Retry> instead of L<HTTP::Tiny>.
 See the documentation of HTTP::Tiny::Retry for more details.
@@ -491,6 +626,7 @@ and continue. Will return with the last error response.
 
 =item * B<urls>* => I<array[str]>
 
+
 =back
 
 Returns an enveloped result (an array).
@@ -526,7 +662,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019, 2018 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2019, 2018 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
